parse_type_annotation

Function parse_type_annotation 

pub fn parse_type_annotation(
    s: &str,
    type_aliases: &HashMap<String, VarType>,
    resolved_imports: &HashMap<String, ImportedNamespace>,
) -> Result<VarType, String>
Parses a type annotation string into a VarType.

Errors

Returns an error string if the type annotation syntax is invalid or references an unknown type alias.